function [M_TOTAL]=mission4_optim_mass(vari)

%% INTRODUZIONE:
% Codice di ottimizzazione dell'orbita di parcheggio marziana.
% INPUT: Condizioni di cattura e fuga dal pianeta in termini di:
% - Eccesso Iperbolico di Velocita' --> Energia Caratteristica C3
% - Data di cattura e di fuga --> Julian Day
% - Dati orbitali di parcheggio --> Eccentricità, Semiasse e Inclinazione
% OUTPUT:
% - Argomento del periastro --> vari(1)
% - Ascensione retta del nodo ascendente orbita di parcheggio --> vari(2)
% - Punto di injection per la cattura --> vari(3)
% - Punto di Injection per la fuga --> vari(4)
% - Argomento del periastro lander --> vari(5)
% - Ascensione retta del nodo ascendente lander --> vari(6)
% - Punto di injection per la cattura lander --> vari(7)
% - eccentricità parking orbit orbiter--> vari(8)
% - eccentricità parking orbit lander --> vari(9)
%% DATI DI INPUT --> variIABILI GLOBALI
global a_orbit i_orbit C3_c delta_t Perturbation1 Perturbation2
global ra_capture ra_escape dec_capture dec_escape mu C3_e C3_c_lander ra_capture_lander dec_capture_lander
global mi_ritorno_orbiter mu_arrivo_orbiter
global ms_arrivo_orbiter mp_arrivo_orbiter mp_ritorno_orbiter ms_ritorno_orbiter
global DV_CAPTURE_orbiter DV_ESCAPE_orbiter DV_TOTAL_orbiter

global mu_arrivo_lander mi_ascesa_lander mi_discesa_lander M_TOTAL_orbiter M_TOTAL_lander
global DV_CAPTURE_lander deltav_ascesa_lander deltav_discesa_lander
global mp_ascesa_lander ms_ascesa_lander mp_discesa_lander ms_discesa_lander mp_arrivo_lander ms_arrivo_lander mu_discesa_lander

%% MASSE
mu_ritorno_orbiter=200; 
mu_ascesa_lander=50; 

Isp_MAV=300;
g0=9.81;
c_MAV=Isp_MAV*g0/1000; 

Isp=450; %LOX/LH2
c=Isp*g0/1000;


%% PERTURBAZIONE
t=delta_t*86400;
tao=sqrt(mu/a_orbit^3);
J2=1.9595*10^-3;
R_mars=3389.5;
p_orbit=a_orbit*(1-vari(8)^2);
Perturbation1=-3/2*J2*tao*(R_mars/p_orbit)^2*cos(i_orbit);
Perturbation2=3/2*J2*tao*(R_mars/p_orbit)^2*(2-5/2*sin(i_orbit).^2);

%% VETTORI FONDAMENTALI E MATRICI DI ROTAZIONE
X=[1;0;0];                  
Y=[0;1;0];
Z=[0;0;1];
%sulla parte della cattura si avrà una parte relativa all'orbiter e una al
%lander. Mentre per l'evasione vi sarà solo l'orbiter quindi non si
%specifica nulla
R_RAAN_3_capture_orb=[cos(vari(2)) -sin(vari(2)) 0;sin(vari(2)) cos(vari(2)) 0;0 0 1];
R_i_1_orb= [1 0 0; 0 cos(i_orbit) -sin(i_orbit);0 sin(i_orbit) cos(i_orbit)];
R_inj_3_capture_orb=[cos(vari(3)) -sin(vari(3)) 0;sin(vari(3)) cos(vari(3)) 0;0 0 1];
R_ra_capture_3_orb=[cos(ra_capture) -sin(ra_capture) 0;sin(ra_capture) cos(ra_capture) 0;0 0 1];
R_dec_capture_2_orb=[cos(dec_capture) 0 sin(dec_capture);0 1 0; -sin(dec_capture) 0 cos(dec_capture)];

R_RAAN_3_escape=[cos(vari(2)+Perturbation1*t) -sin(vari(2)+Perturbation1*t) 0;sin(vari(2)+Perturbation1*t) cos(vari(2)+Perturbation1*t) 0;0 0 1];
R_ra_escape_3=[cos(ra_escape) -sin(ra_escape) 0;sin(ra_escape) cos(ra_escape) 0;0 0 1];
R_dec_escape_2=[cos(dec_escape) 0 sin(dec_escape);0 1 0; -sin(dec_escape) 0 cos(dec_escape)];
R_inj_3_escape=[cos(vari(4)) -sin(vari(4)) 0;sin(vari(4)) cos(vari(4)) 0;0 0 1];

%% FASE DI CATTURA --> DEFINIZIONE PARAMETRI ORBITALI E DV DI CATTURA
A_vector_capture_orb=(R_RAAN_3_capture_orb*R_i_1_orb*X);                        % Vettore nodo ascendente
nu_capture_orb=2*pi+vari(3)-vari(1);   % Anomalia Vera P.O. [rad]
r_mod_capture_orb=a_orbit*(1-vari(8)^2)/(1+vari(8)*cos(nu_capture_orb));  % Modulo vettore di capture [km]
r_dir_capture_orb=R_RAAN_3_capture_orb*R_i_1_orb*R_inj_3_capture_orb*X;          % Direzione Vettore posizione P.O.
r_capture_orb=r_mod_capture_orb*r_dir_capture_orb;                              % Vettore Posizione P.O. [km]
V_mod_capture_orb=sqrt(2*mu/r_mod_capture_orb-mu/a_orbit);                % Modulo velocità P.O. [km/s]
fpa_capture_orb=asin(sqrt(mu*a_orbit*(1-vari(8)^2))/...               % Flight Path Angle [rad]
    (r_mod_capture_orb*V_mod_capture_orb));   
if fpa_capture_orb<0                                   % Condizione Flight Path Angle - No valore negativo
    fpa_capture_orb=fpa_capture_orb+2*pi;
end 
if nu_capture_orb<0                                    % Condizione Anomalia Vera - No valore negativo
    nu_capture_orb=2*pi+nu_capture_orb;
end
angle_capture_orb=vari(3)-vari(1);                       % Angolo tra periastro e posizione - Anomalia vera [rad]

%% MODIFICA - fpa cambia valore solo se sono almeno 1 grado negativo
if angle_capture_orb<-0.01*pi/180                         % No valore negativo
    angle_capture_orb=angle_capture_orb+2*pi;
end
if angle_capture_orb>=-0.01*pi/180 && angle_capture_orb<=pi           % Controllo range del Flight Path Angle 
    if fpa_capture_orb>=0 && fpa_capture_orb<=pi/2         % Prima meta' orbita: 0<fpa<pi/2
        fpa_capture_orb=fpa_capture_orb;                                    
    else
        fpa_capture_orb=fpa_capture_orb-pi/2;
    end
end
if angle_capture_orb>pi && angle_capture_orb<=2*pi          % Seconda meta' orbita: pi/2<fpa<pi
     
     if fpa_capture_orb>pi/2 && fpa_capture_orb<=pi
         fpa_capture_orb=fpa_capture_orb;
     else
         fpa_capture_orb=pi-fpa_capture_orb;
     end            
end
R_fpa_3_capture_orb=[cos(fpa_capture_orb) -sin(fpa_capture_orb) 0;sin(fpa_capture_orb) cos(fpa_capture_orb) 0;0 0 1]; 
V_dir_capture_orb=R_RAAN_3_capture_orb*R_i_1_orb...               % Direzione Velocità capture
    *R_inj_3_capture_orb*R_fpa_3_capture_orb*X;    


V_capture_orb=V_mod_capture_orb*V_dir_capture_orb;                  % Vettore Velocità capture  [km/s]
S_vector_capture_orb=(R_ra_capture_3_orb*R_dec_capture_2_orb'*X);   % Vettore Asintoto iperbole capture
sigma_capture_orb=C3_c*r_mod_capture_orb/(2*mu);            % Parametro adimensionale 
a_h_capture_orb=-mu/C3_c;                             % Semiasse Iperbole [km]
% DEFINIZIONE DELLE IPERBOLE POSSIBILI: definito un asintoto e fissato
% un vettore posizione di injection (modulo e direzione) si trovano due
% iperbole con eccentricità diverse che soddisfano la direzione
% dell'asintoto e il livello energetico (C3).


%% CASO 1: 
Beta_capture_1_orb=acos(S_vector_capture_orb'*r_dir_capture_orb);                                   % Angolo Posizione- Asintoto [rad]
 tan_phiA_capture_1_orb=sigma_capture_orb*sin(Beta_capture_1_orb)+sqrt(((1+sigma_capture_orb)^2)...
  -(1+sigma_capture_orb*cos(Beta_capture_1_orb))^2);
e_h_capture_1_orb=sqrt(tan_phiA_capture_1_orb^2+1);                                             % Eccentricita' prima Iperbole
phiA_capture_1_orb=acos(-1/e_h_capture_1_orb);                                                  % Angolo periastro - asintoto [rad]
phi_capture_1_orb=-(phiA_capture_1_orb- Beta_capture_1_orb);                                         % Anomalia vera Injection iperbole [rad]
%if phi_capture_1_orb<0                                                                      % Controllo anomalia vera - No negativa
%     phi_capture_1_orb=phi_capture_1_orb+2*pi;
% end
if phi_capture_1_orb>2*pi                                                                      % Controllo anomalia vera - No negativa
    phi_capture_1_orb=phi_capture_1_orb-2*pi;
end
r_hyp_capture_1_orb=a_h_capture_orb*(1-e_h_capture_1_orb^2)/...                                     % Raggio in valori iperbolici 
    (1+e_h_capture_1_orb*cos(phi_capture_1_orb));                                               % deve essere uguale a quello dell'orbita
V_h_mod_capture_1_orb=sqrt(C3_c+2*mu/r_hyp_capture_1_orb);                                % Modulo velocità iperbolica [km/s]
h_h_capture_1_orb=mu*sqrt((e_h_capture_1_orb^2-1)/C3_c);                                  % Momento angolare iperbole
fpa_h_capture_1_orb=asin(h_h_capture_1_orb/(r_hyp_capture_1_orb*V_h_mod_capture_1_orb));                % Flight Path Angle Iperbole [rad]
if phi_capture_1_orb<-0.001                                                                 % Condizioni Angoli
    phi_capture_1_orb=phi_capture_1_orb+2*pi;
end
if phi_capture_1_orb>=-0.001 && phi_capture_1_orb<=pi
    if fpa_h_capture_1_orb>=0 && fpa_h_capture_1_orb<=pi/2
        fpa_h_capture_1_orb=fpa_h_capture_1_orb;
    else
        fpa_h_capture_1_orb=fpa_h_capture_1_orb-pi/2;
    end
end
if phi_capture_1_orb>pi && phi_capture_1_orb<2*pi
    if fpa_h_capture_1_orb>pi/2 && fpa_h_capture_1_orb<=pi
        fpa_h_capture_1_orb=fpa_h_capture_1_orb;
    else
        fpa_h_capture_1_orb=pi-fpa_h_capture_1_orb;
    end

end

W_dir_capture_1_orb=cross(S_vector_capture_orb,r_dir_capture_orb)/sin(Beta_capture_1_orb);              % Versore Momento angolare iperbole
V_h_dir_capture_1_orb=(r_dir_capture_orb*cos(fpa_h_capture_1_orb)+...                               % Direzione velocità iperbolica capture
    cross(W_dir_capture_1_orb, r_dir_capture_orb)*sin(fpa_h_capture_1_orb));         
V_h_capture_1_orb=V_h_dir_capture_1_orb*V_h_mod_capture_1_orb;                                      % Velocità iperbolica cattura [km/s]
Delta_V_capture_1_orbiter=sqrt((V_capture_orb-V_h_capture_1_orb)'*(V_capture_orb-V_h_capture_1_orb));       % DeltaV cattura seconda iperbole [km/s]
p_vector_1_orb=1/mu*((V_h_mod_capture_1_orb^2-mu/r_hyp_capture_1_orb)*r_capture_orb-(r_capture_orb'*V_h_capture_1_orb)*V_h_capture_1_orb);
p_vector_orbit_orb=1/mu*((V_mod_capture_orb^2-mu/r_mod_capture_orb)*r_capture_orb-(r_capture_orb'*V_capture_orb)*V_capture_orb);

%% CASO 2:
Beta_capture_2_orb=2*pi-acos(r_dir_capture_orb'*S_vector_capture_orb);                              % Angolo Posizione- Asintoto [rad]
tan_phiA_capture_2_orb=sigma_capture_orb*sin(Beta_capture_2_orb)+sqrt(((1+sigma_capture_orb)^2)...
   -(1+sigma_capture_orb*cos(Beta_capture_2_orb))^2);
e_h_capture_2_orb=sqrt(tan_phiA_capture_2_orb^2+1);                                             % Eccentricita' seconda Iperbole
phiA_capture_2_orb=acos(-1/e_h_capture_2_orb);                                                  % Angolo periastro - asintoto [rad]
phi_capture_2_orb=-(phiA_capture_2_orb-Beta_capture_2_orb);                                            % Anomalia vera Injection iperbole [rad]
% if phi_capture_2_orb<0                                                                      % Controllo anomalia vera - No negativa
%     phi_capture_2_orb=phi_capture_2+2*pi;
% end
r_hyp_capture_2_orb=a_h_capture_orb*(1-e_h_capture_2_orb^2)/...                                     % Raggio in valori iperbolici 
    (1+e_h_capture_2_orb*cos(phi_capture_2_orb));                                               % deve essere uguale a quello dell'orbita
V_h_mod_capture_2_orb=sqrt(C3_c+2*mu/r_hyp_capture_2_orb);                                % Modulo velocità iperbolica [km/s]
h_h_capture_2_orb=mu*sqrt((e_h_capture_2_orb^2-1)/C3_c);                                  % Momento angolare iperbole
fpa_h_capture_2_orb=asin(h_h_capture_2_orb/(r_hyp_capture_2_orb*V_h_mod_capture_2_orb));                % Flight Path Angle Iperbole [rad]
if phi_capture_2_orb<-0.001                                                                 % Condizioni Angoli
    phi_capture_2_orb=phi_capture_2_orb+2*pi;
end
if phi_capture_2_orb>=-0.001 && phi_capture_2_orb<=pi
    if fpa_h_capture_2_orb>=0 && fpa_h_capture_2_orb<=pi/2
        fpa_h_capture_2_orb=fpa_h_capture_2_orb;
    else
        fpa_h_capture_2_orb=fpa_h_capture_2_orb-pi/2;
    end
end
if phi_capture_2_orb>pi && phi_capture_2_orb<2*pi
    if fpa_h_capture_2_orb>pi/2 && fpa_h_capture_2_orb<=pi
        fpa_h_capture_2_orb=fpa_h_capture_2_orb;
    else
        fpa_h_capture_2_orb=pi-fpa_h_capture_2_orb;
    end
end
W_dir_capture_2_orb=cross(S_vector_capture_orb,r_dir_capture_orb)/sin(Beta_capture_2_orb);              % Versore Momento angolare iperbole
V_h_dir_capture_2_orb=(r_dir_capture_orb*cos(fpa_h_capture_2_orb)+...                               % Direzione velocità iperbolica capture
    cross(W_dir_capture_2_orb, r_dir_capture_orb)*sin(fpa_h_capture_2_orb));  

V_h_capture_2_orb=V_h_dir_capture_2_orb*V_h_mod_capture_2_orb;                                      % Velocità iperbolica cattura [km/s]
p_vector_2_orb=1/mu*((V_h_mod_capture_2_orb^2-mu/r_hyp_capture_2_orb)*r_capture_orb-(r_capture_orb'*V_h_capture_2_orb)*V_h_capture_2_orb);

Delta_V_capture_2_orbiter=sqrt((V_capture_orb-V_h_capture_2_orb)'*(V_capture_orb-V_h_capture_2_orb));       % DeltaV cattura seconda iperbole [km/s]

n_dir_capture_1_orb=cross(Z,W_dir_capture_1_orb);
n_dir_capture_2_orb=cross(Z,W_dir_capture_2_orb);


if Delta_V_capture_1_orbiter < Delta_V_capture_2_orbiter
    DV_CAPTURE_orbiter=Delta_V_capture_1_orbiter;
    assignin('base', 'nodi_c_orbiter', A_vector_capture_orb);
    assignin('base','S_vettore_orbiter',S_vector_capture_orb);
    assignin('base','e_h_capture_orbiter',e_h_capture_1_orb);
    assignin('base','R_vettore_orbiter',r_capture_orb);
    assignin('base','a_h_capture_orbiter',a_h_capture_orb);
    assignin('base','e_h_capture_2_orbiter',e_h_capture_2_orb);
    assignin('base','phi_A_capture_orbiter',phiA_capture_1_orb);
    assignin('base','p_vector_orbiter',p_vector_1_orb);
    assignin('base','p_vector_2_orbiter',p_vector_2_orb);
    assignin('base','n_capture_orbiter',n_dir_capture_1_orb)
    assignin('base','n_capture_2_orbiter',n_dir_capture_2_orb)
    assignin('base','W_h_capture_orbiter',W_dir_capture_1_orb)
    assignin('base','W_h_capture_2_orbiter',W_dir_capture_2_orb)
    assignin('base','r_capture_orbiter',r_capture_orb)
    assignin('base','V_capture_orbiter',V_capture_orb)
    assignin('base','V_h_capture_orbiter',V_h_capture_1_orb)
    assignin('base','V_h_capture_2_orbiter',V_h_capture_2_orb)
    assignin('base','phi_capture_orbiter',phi_capture_1_orb)
else
    DV_CAPTURE_orbiter=Delta_V_capture_2_orbiter;
    assignin('base', 'nodi_c_orbiter', A_vector_capture_orb);
    assignin('base','S_vettore_orbiter',S_vector_capture_orb);
    assignin('base','e_h_capture_orbiter',e_h_capture_2_orb);
    assignin('base','e_h_capture_2_orbiter',e_h_capture_1_orb);
    assignin('base','R_vettore_orbiter',r_capture_orb);
    assignin('base','a_h_capture_orbiter',a_h_capture_orb);
    assignin('base','phi_A_capture_orbiter',phiA_capture_2_orb);
    assignin('base','p_vector_orbiter',p_vector_2_orb);
        assignin('base','p_vector_2_orbiter',p_vector_1_orb);
        assignin('base','n_capture_orbiter',n_dir_capture_2_orb)
        assignin('base','n_capture_2_orbiter',n_dir_capture_1_orb)
        assignin('base','W_h_capture_orbiter',W_dir_capture_2_orb)
        assignin('base','W_h_capture_2_orbiter',W_dir_capture_1_orb)   
    assignin('base','r_capture_orbiter',r_capture_orb)
    assignin('base','V_capture_orbiter',V_capture_orb)
    assignin('base','V_h_capture_orbiter',V_h_capture_2_orb)
    assignin('base','V_h_capture_2_orbiter',V_h_capture_1_orb)
    assignin('base','phi_capture_orbiter',phi_capture_2_orb)
end


%% FASE DI EVASIONE --> DEFINIZIONE PARAMETRI ORBITALI E DV DI EVASIONE

A_vector_escape=R_RAAN_3_escape*R_i_1_orb*X;                         % Vettore nodo ascendente
nu_escape=2*pi+vari(4)-(vari(1)+Perturbation2*t);               % Anomalia Vera P.O. [rad]
r_mod_escape=a_orbit*(1-vari(8)^2)/(1+vari(8)*cos(nu_escape));   % Modulo vettore di escape [km]
r_dir_escape=R_RAAN_3_escape*R_i_1_orb*R_inj_3_escape*X;            % Direzione Vettore posizione P.O.
r_escape=r_mod_escape*r_dir_escape;                                % Vettore Posizione P.O. [km]
V_mod_escape=sqrt(2*mu/r_mod_escape-mu/a_orbit);                 % Modulo velocità P.O. [km/s]
fpa_escape=asin(sqrt(mu*a_orbit*(1-vari(8)^2))/...               % Flight Path Angle [rad]
    (r_mod_escape*V_mod_escape));   
if fpa_escape<0                                   % Condizione Flight Path Angle - No valore negativo
    fpa_escape=fpa_escape+2*pi;
end 
if nu_escape<0                                    % Condizione Anomalia Vera - No valore negativo
    nu_escape=2*pi+nu_escape;
end
angle_escape=vari(4)-(vari(1)+Perturbation2*t);                       % Angolo tra periastro e posizione - Anomalia vera [rad]

%% MODIFICA - fpa cambia valore solo se sono almeno 1 grado negativo
if angle_escape<-0.01*pi/180                                % No valore negativo
    angle_escape=angle_escape+2*pi;
end
if angle_escape>=-0.01*pi/180 && angle_escape<=pi            % Controllo range del Flight Path Angle 
    if fpa_escape>=0 && fpa_escape<=pi/2          % Prima meta' orbita: 0<fpa<pi/2
        fpa_escape=fpa_escape;                                    
    else
        fpa_escape=fpa_escape-pi/2;
    end 
end
if angle_escape>pi && angle_escape<2*pi          % Seconda meta' orbita: pi/2<fpa<pi
   fpa_escape=-fpa_escape;
    if fpa_escape>pi/2 && fpa_escape<=pi
        fpa_escape=fpa_escape;
    else
        fpa_escape=pi-fpa_escape;
    end
end

    R_fpa_3_escape=[cos(fpa_escape) -sin(fpa_escape) 0;sin(fpa_escape) cos(fpa_escape) 0;0 0 1]; 
V_dir_escape=R_RAAN_3_escape*R_i_1_orb...               % Direzione Velocità escape
    *R_inj_3_escape*R_fpa_3_escape*X;                
V_escape=V_mod_escape*V_dir_escape;                   % Vettore Velocità escape  [km/s]
S_vector_escape=(R_ra_escape_3*R_dec_escape_2'*X);    % Vettore Asintoto iperbole escape
sigma_escape=C3_e*r_mod_escape/(2*mu);             % Parametro adimensionale 
a_h_escape=-mu/C3_e;                             % Semiasse Iperbole [km]

% DEFINIZIONE DELLE IPERBOLE POSSIBILI: definito un asintoto e fissato
% un vettore posizione di injection (modulo e direzione) si trovano due
% iperbole con eccentricità diverse che soddisfano la direzione
% dell'asintoto e il livello energetico (C3).

%% CASO 1: 
Beta_escape_1=acos(r_dir_escape'*S_vector_escape);                                   % Angolo Posizione- Asintoto [rad]
tan_phiA_escape_1=-sigma_escape*sin(Beta_escape_1)-sqrt(((1+sigma_escape)^2)...
    -(1+sigma_escape*cos(Beta_escape_1))^2);
e_h_escape_1=sqrt(tan_phiA_escape_1^2+1);                                             % Eccentricita' prima Iperbole
phiA_escape_1=acos(-1/e_h_escape_1);                                                  % Angolo periastro - asintoto [rad]
phi_escape_1=(phiA_escape_1-Beta_escape_1);                                             % Anomalia vera Injection iperbole [rad]
%if phi_escape_1<0                                                                     % Controllo anomalia vera - No negativa
%   phi_escape_1=phi_escape_1+2*pi;
%end
r_hyp_escape_1=a_h_escape*(1-e_h_escape_1^2)/...                                      % Raggio in valori iperbolici 
    (1+e_h_escape_1*cos(phi_escape_1));                                               % deve essere uguale a quello dell'orbita
V_h_mod_escape_1=sqrt(C3_e+2*mu/r_hyp_escape_1);                                 % Modulo velocità iperbolica [km/s]
h_h_escape_1=mu*sqrt((e_h_escape_1^2-1)/C3_e);                                   % Momento angolare iperbole
fpa_h_escape_1=asin(h_h_escape_1/(r_hyp_escape_1*V_h_mod_escape_1));                  % Flight Path Angle Iperbole [rad]
if phi_escape_1<-0.001                                                                % Condizioni Angoli
    phi_escape_1=phi_escape_1+2*pi;
end
if phi_escape_1>=-0.001 && phi_escape_1<=pi
    if fpa_h_escape_1>=0 && fpa_h_escape_1<=pi/2
        fpa_h_escape_1=fpa_h_escape_1;
    else
        fpa_h_escape_1=fpa_h_escape_1-pi/2;
    end
end
if phi_escape_1>pi && phi_escape_1<2*pi
    if fpa_h_escape_1>pi/2 && fpa_h_escape_1<=pi
        fpa_h_escape_1=fpa_h_escape_1;
    else
        fpa_h_escape_1=pi-fpa_h_escape_1;
    end
end
%W_dir_escape_1=cross(S_vector_escape,r_dir_escape)/sin(-Beta_escape_1);
W_dir_escape_1=cross(r_dir_escape,S_vector_escape)/sin(Beta_escape_1);               % Versore Momento angolare iperbole
V_h_dir_escape_1=(r_dir_escape*cos(fpa_h_escape_1)+...                               % Direzione velocità iperbolica escape
    cross(W_dir_escape_1, r_dir_escape)*sin(fpa_h_escape_1));         
V_h_escape_1=V_h_dir_escape_1*V_h_mod_escape_1;                                      % Velocità iperbolica cattura [km/s]
Delta_V_escape_1_orbiter=sqrt((V_escape-V_h_escape_1)'*(V_escape-V_h_escape_1));             % DeltaV cattura seconda iperbole [km/s]
p_escape_1=1/mu*((V_h_mod_escape_1^2-mu/r_hyp_escape_1)*r_escape-(r_escape'*V_h_escape_1)*V_h_escape_1);

%% CASO 2:
Beta_escape_2=2*pi-acos(r_dir_escape'*S_vector_escape);                              % Angolo Posizione- Asintoto [rad]
tan_phiA_escape_2=-sigma_escape*sin(Beta_escape_2)-sqrt(((1+sigma_escape)^2)...
    -(1+sigma_escape*cos(Beta_escape_2))^2);
e_h_escape_2=sqrt(tan_phiA_escape_2^2+1);                                            % Eccentricita' seconda Iperbole
phiA_escape_2=acos(-1/e_h_escape_2);                                                 % Angolo periastro - asintoto [rad]
phi_escape_2=(phiA_escape_2-Beta_escape_2);                                            % Anomalia vera Injection iperbole [rad]
% if phi_escape_2<0                                                                    % Controllo anomalia vera - No negativa
%     phi_escape_2=phi_escape_2+2*pi;
% end
r_hyp_escape_2=a_h_escape*(1-e_h_escape_2^2)/...                                     % Raggio in valori iperbolici 
    (1+e_h_escape_2*cos(phi_escape_2));                                              % deve essere uguale a quello dell'orbita
V_h_mod_escape_2=sqrt(C3_e+2*mu/r_hyp_escape_2);                                % Modulo velocità iperbolica [km/s]
h_h_escape_2=mu*sqrt((e_h_escape_2^2-1)/C3_e);                                  % Momento angolare iperbole
fpa_h_escape_2=asin(h_h_escape_2/(r_hyp_escape_2*V_h_mod_escape_2));                 % Flight Path Angle Iperbole [rad]
if phi_escape_2<-0.001                                                               % Condizioni Angoli
    phi_escape_2=phi_escape_2+2*pi;
end
if phi_escape_2>=-0.001 && phi_escape_2<=pi
    if fpa_h_escape_2>=0 && fpa_h_escape_2<=pi/2
        fpa_h_escape_2=fpa_h_escape_2;
    else
        fpa_h_escape_2=fpa_h_escape_2-pi/2;
    end
end
if phi_escape_2>pi && phi_escape_2<2*pi
    if fpa_h_escape_2>pi/2 && fpa_h_escape_2<=pi
        fpa_h_escape_2=fpa_h_escape_2;
    else
        fpa_h_escape_2=pi-fpa_h_escape_2;
    end
end
%W_dir_escape_2=cross(S_vector_escape,r_dir_escape)/sin(-Beta_escape_2);               % Versore Momento angolare iperbole
W_dir_escape_2=cross(r_dir_escape,S_vector_escape)/sin(Beta_escape_2);
V_h_dir_escape_2=(r_dir_escape*cos(fpa_h_escape_2)+...                               % Direzione velocità iperbolica escape
    cross(W_dir_escape_2, r_dir_escape)*sin(fpa_h_escape_2));         
V_h_escape_2=V_h_dir_escape_2*V_h_mod_escape_2;                                      % Velocità iperbolica cattura [km/s]
Delta_V_escape_2_orbiter=sqrt((V_escape-V_h_escape_2)'*(V_escape-V_h_escape_2));         % DeltaV cattura seconda iperbole [km/s]
p_escape_2=1/mu*((V_h_mod_escape_2^2-mu/r_hyp_escape_2)*r_escape-(r_escape'*V_h_escape_2)*V_h_escape_2);


n_dir_escape_1=cross(Z,W_dir_escape_1);
n_dir_escape_2=cross(Z,W_dir_escape_2);

if Delta_V_escape_1_orbiter < Delta_V_escape_2_orbiter
    DV_ESCAPE_orbiter=Delta_V_escape_1_orbiter;
    assignin('base', 'nodi_e_orbiter', A_vector_escape);
    assignin('base','S_vettore_e_orbiter',S_vector_escape);
    assignin('base','e_h_escape_orbiter',e_h_escape_1);
    assignin('base','e_h_escape_2_orbiter',e_h_escape_2);
    assignin('base','R_vettore_e_orbiter',r_escape);
    assignin('base','a_h_escape_orbiter',a_h_escape);
    assignin('base','phi_A_escape_orbiter',phiA_escape_1);
    assignin('base', 'p_escape_orbiter',p_escape_1);
        assignin('base', 'p_escape_2_orbiter',p_escape_2);
        assignin('base','n_escape_orbiter',n_dir_escape_1);
        assignin('base','n_escape_2_orbiter',n_dir_escape_2);
        assignin('base','W_h_escape_orbiter',W_dir_escape_1);
        assignin('base','W_h_escape_2_orbiter',W_dir_escape_2)
            assignin('base','r_escape_orbiter',r_escape)
    assignin('base','V_escape_orbiter',V_escape)
    assignin('base','V_h_escape_orbiter',V_h_escape_1)
    assignin('base','V_h_escape_2_orbiter',V_h_escape_2)
    assignin('base','phi_escape_orbiter',phi_escape_1)
    
else
    DV_ESCAPE_orbiter=Delta_V_escape_2_orbiter;
    assignin('base', 'nodi_e_orbiter', A_vector_escape);
    assignin('base','S_vettore_e_orbiter',S_vector_escape);
    assignin('base','e_h_escape_orbiter',e_h_escape_2);
    assignin('base','e_h_escape_2_orbiter',e_h_escape_1);
    assignin('base','R_vettore_e_orbiter',r_escape);
    assignin('base','a_h_escape_orbiter',a_h_escape);
    assignin('base','phi_A_escape_orbiter',phiA_escape_2);
    assignin('base', 'p_escape_orbiter',p_escape_2);
        assignin('base', 'p_escape_2_orbiter',p_escape_1);
        assignin('base','n_escape_orbiter',n_dir_escape_2)
        assignin('base','n_escape_2_orbiter',n_dir_escape_1)
        assignin('base','W_h_escape_orbiter',W_dir_escape_2)
        assignin('base','W_h_escape_2_orbiter',W_dir_escape_1)
    assignin('base','r_escape_orbiter',r_escape)
    assignin('base','V_escape_orbiter',V_escape)
    assignin('base','V_h_escape_orbiter',V_h_escape_2)
    assignin('base','V_h_escape_2_orbiter',V_h_escape_1)
    assignin('base','phi_escape_orbiter',phi_escape_2)
end
DV_TOTAL_orbiter=DV_CAPTURE_orbiter+DV_ESCAPE_orbiter;
assignin('base', 'DV_Capture_1_orbiter', Delta_V_capture_1_orbiter);
assignin('base', 'DV_Capture_2_orbiter', Delta_V_capture_2_orbiter);
assignin('base', 'DV_Escape_1_orbiter', Delta_V_escape_1_orbiter);
assignin('base', 'DV_Escape_2_orbiter', Delta_V_escape_2_orbiter);

%calcolo masse all'arrivo sulla Terra dell'orbiter
mi_ritorno_orbiter=(mu_ritorno_orbiter)/(exp(-(DV_ESCAPE_orbiter/c))-0.1+0.1*(exp(-(DV_ESCAPE_orbiter/c))));
mp_ritorno_orbiter=(mi_ritorno_orbiter-mu_ritorno_orbiter)/1.1;
ms_ritorno_orbiter=0.1*mp_ritorno_orbiter;

%calcolo masse all'arrivo su Marte dell'orbiter
mu_arrivo_orbiter=mi_ritorno_orbiter-mu_ascesa_lander;
M_TOTAL_orbiter=(mu_arrivo_orbiter)/(exp(-(DV_CAPTURE_orbiter/c))-0.1+0.1*(exp(-(DV_CAPTURE_orbiter/c))));
mp_arrivo_orbiter=(M_TOTAL_orbiter-mu_arrivo_orbiter)/1.1;
ms_arrivo_orbiter=0.1*mp_arrivo_orbiter;

%% parte lander

%ascesa
r0=3389.5;
rp=a_orbit*(1-vari(9));
energia=-(mu/(2*a_orbit));
v2=sqrt(2*(energia+mu/rp));
a1=(rp+r0)/2;
energia1=-(mu/(2*a1));
v0=sqrt(2*(energia1+mu/r0));
v1=sqrt(2*(energia1+mu/rp));
dv1=v2-v1;
deltav_ascesa_lander=1.1*v0+dv1;
mi_ascesa_lander=(mu_ascesa_lander)/(exp(-(deltav_ascesa_lander/c_MAV))-0.1+0.1*(exp(-(deltav_ascesa_lander/c_MAV))));
mp_ascesa_lander=(mi_ascesa_lander-mu_ascesa_lander)/1.1;
ms_ascesa_lander=0.1*mp_ascesa_lander;

%discesa
mu_discesa_lander=900+mi_ascesa_lander;
deltav_discesa_lander=dv1;
mi_discesa_lander=(mu_discesa_lander)/(exp(-(deltav_discesa_lander/c_MAV))-0.1+0.1*(exp(-(deltav_discesa_lander/c_MAV))));
mp_discesa_lander=(mi_discesa_lander-mu_discesa_lander)/1.1;
ms_discesa_lander=0.1*mp_discesa_lander;

%% VETTORI FONDAMENTALI E MATRICI DI ROTAZIONE

R_RAAN_3_capture_lander=[cos(vari(6)) -sin(vari(6)) 0;sin(vari(6)) cos(vari(6)) 0;0 0 1];
R_i_1_lander= [1 0 0; 0 cos(i_orbit) -sin(i_orbit);0 sin(i_orbit) cos(i_orbit)];
R_inj_3_capture_lander=[cos(vari(7)) -sin(vari(7)) 0;sin(vari(7)) cos(vari(7)) 0;0 0 1];
R_ra_capture_3_lander=[cos(ra_capture_lander) -sin(ra_capture_lander) 0;sin(ra_capture_lander) cos(ra_capture_lander) 0;0 0 1];
R_dec_capture_2_lander=[cos(dec_capture_lander) 0 sin(dec_capture_lander);0 1 0; -sin(dec_capture_lander) 0 cos(dec_capture_lander)];

%% FASE DI CATTURA --> DEFINIZIONE PARAMETRI ORBITALI E DV DI CATTURA
A_vector_capture_lander=(R_RAAN_3_capture_lander*R_i_1_lander*X);                        % Vettore nodo ascendente
nu_capture_lander=2*pi+vari(7)-vari(5);                                                  % Anomalia Vera P.O. [rad]
r_mod_capture_lander=a_orbit*(1-vari(9)^2)/(1+vari(9)*cos(nu_capture_lander));           % Modulo vettore di capture [km]
r_dir_capture_lander=R_RAAN_3_capture_lander*R_i_1_lander*R_inj_3_capture_lander*X;      % Direzione Vettore posizione P.O.
r_capture_lander=r_mod_capture_lander*r_dir_capture_lander;                              % Vettore Posizione P.O. [km]
V_mod_capture_lander=sqrt(2*mu/r_mod_capture_lander-mu/a_orbit);                         % Modulo velocità P.O. [km/s]
fpa_capture_lander=asin(sqrt(mu*a_orbit*(1-vari(9)^2))/...                               % Flight Path Angle [rad]
    (r_mod_capture_lander*V_mod_capture_lander));   
if fpa_capture_lander<0                                                                  % Condizione Flight Path Angle - No valore negativo
    fpa_capture_lander=fpa_capture_lander+2*pi;
end 
if nu_capture_lander<0                                                                  % Condizione Anomalia Vera - No valore negativo
    nu_capture_lander=2*pi+nu_capture_lander;
end
angle_capture_lander=vari(7)-vari(5);                                                    % Angolo tra periastro e posizione - Anomalia vera [rad]

%% MODIFICA - fpa cambia valore solo se sono almeno 1 grado negativo
if angle_capture_lander<-0.01*pi/180                                % No valore negativo
    angle_capture_lander=angle_capture_lander+2*pi;
end
if angle_capture_lander>=-0.01*pi/180 && angle_capture_lander<=pi           % Controllo range del Flight Path Angle 
    if fpa_capture_lander>=0 && fpa_capture_lander<=pi/2                      % Prima meta' orbita: 0<fpa<pi/2
        fpa_capture_lander=fpa_capture_lander;                                    
    else
        fpa_capture_lander=fpa_capture_lander-pi/2;
    end
end
if angle_capture_lander>pi && angle_capture_lander<=2*pi                     % Seconda meta' orbita: pi/2<fpa<pi
     
     if fpa_capture_lander>pi/2 && fpa_capture_lander<=pi
         fpa_capture_lander=fpa_capture_lander;
     else
         fpa_capture_lander=pi-fpa_capture_lander;
     end            
end
R_fpa_3_capture_lander=[cos(fpa_capture_lander) -sin(fpa_capture_lander) 0;sin(fpa_capture_lander) cos(fpa_capture_lander) 0;0 0 1]; 
V_dir_capture_lander=R_RAAN_3_capture_lander*R_i_1_lander...               % Direzione Velocità capture
    *R_inj_3_capture_lander*R_fpa_3_capture_lander*X;    
V_capture_lander=V_mod_capture_lander*V_dir_capture_lander;                  % Vettore Velocità capture  [km/s]
S_vector_capture_lander=(R_ra_capture_3_lander*R_dec_capture_2_lander'*X);   % Vettore Asintoto iperbole capture
sigma_capture_lander=C3_c_lander*r_mod_capture_lander/(2*mu);                            % Parametro adimensionale 
a_h_capture_lander=-mu/C3_c_lander;                                                   % Semiasse Iperbole [km]
% DEFINIZIONE DELLE IPERBOLE POSSIBILI: definito un asintoto e fissato
% un vettore posizione di injection (modulo e direzione) si trovano due
% iperbole con eccentricità diverse che soddisfano la direzione
% dell'asintoto e il livello energetico (C3).


%% CASO 1: 
Beta_capture_1_lander=acos(S_vector_capture_lander'*r_dir_capture_lander);                                   % Angolo Posizione- Asintoto [rad]
 tan_phiA_capture_1_lander=sigma_capture_lander*sin(Beta_capture_1_lander)+sqrt(((1+sigma_capture_lander)^2)...
  -(1+sigma_capture_lander*cos(Beta_capture_1_lander))^2);
e_h_capture_1_lander=sqrt(tan_phiA_capture_1_lander^2+1);                                             % Eccentricita' prima Iperbole
phiA_capture_1_lander=acos(-1/e_h_capture_1_lander);                                                  % Angolo periastro - asintoto [rad]
phi_capture_1_lander=-(phiA_capture_1_lander- Beta_capture_1_lander);                                         % Anomalia vera Injection iperbole [rad]
%if phi_capture_1_lander<0                                                                      % Controllo anomalia vera - No negativa
%     phi_capture_1_lander=phi_capture_1_lander+2*pi;
% end
if phi_capture_1_lander>2*pi                                                                      % Controllo anomalia vera - No negativa
    phi_capture_1_lander=phi_capture_1_lander-2*pi;
end
r_hyp_capture_1_lander=a_h_capture_lander*(1-e_h_capture_1_lander^2)/...                                     % Raggio in valori iperbolici 
    (1+e_h_capture_1_lander*cos(phi_capture_1_lander));                                               % deve essere uguale a quello dell'orbita
V_h_mod_capture_1_lander=sqrt(C3_c_lander+2*mu/r_hyp_capture_1_lander);                                % Modulo velocità iperbolica [km/s]
h_h_capture_1_lander=mu*sqrt((e_h_capture_1_lander^2-1)/C3_c_lander);                                  % Momento angolare iperbole
fpa_h_capture_1_lander=asin(h_h_capture_1_lander/(r_hyp_capture_1_lander*V_h_mod_capture_1_lander));                % Flight Path Angle Iperbole [rad]
if phi_capture_1_lander<-0.001                                                                 % Condizioni Angoli
    phi_capture_1_lander=phi_capture_1_lander+2*pi;
end
if phi_capture_1_lander>=-0.001 && phi_capture_1_lander<=pi
    if fpa_h_capture_1_lander>=0 && fpa_h_capture_1_lander<=pi/2
        fpa_h_capture_1_lander=fpa_h_capture_1_lander;
    else
        fpa_h_capture_1_lander=fpa_h_capture_1_lander-pi/2;
    end
end
if phi_capture_1_lander>pi && phi_capture_1_lander<2*pi
    if fpa_h_capture_1_lander>pi/2 && fpa_h_capture_1_lander<=pi
        fpa_h_capture_1_lander=fpa_h_capture_1_lander;
    else
        fpa_h_capture_1_lander=pi-fpa_h_capture_1_lander;
    end

end

W_dir_capture_1_lander=cross(S_vector_capture_lander,r_dir_capture_lander)/sin(Beta_capture_1_lander);              % Versore Momento angolare iperbole
V_h_dir_capture_1_lander=(r_dir_capture_lander*cos(fpa_h_capture_1_lander)+...                               % Direzione velocità iperbolica capture
    cross(W_dir_capture_1_lander, r_dir_capture_lander)*sin(fpa_h_capture_1_lander));         
V_h_capture_1_lander=V_h_dir_capture_1_lander*V_h_mod_capture_1_lander;                                      % Velocità iperbolica cattura [km/s]
Delta_V_capture_1_lander=sqrt((V_capture_lander-V_h_capture_1_lander)'*(V_capture_lander-V_h_capture_1_lander));       % DeltaV cattura seconda iperbole [km/s]
p_vector_1_lander=1/mu*((V_h_mod_capture_1_lander^2-mu/r_hyp_capture_1_lander)*r_capture_lander-(r_capture_lander'*V_h_capture_1_lander)*V_h_capture_1_lander);
p_vector_orbit_lander=1/mu*((V_mod_capture_lander^2-mu/r_mod_capture_lander)*r_capture_lander-(r_capture_lander'*V_capture_lander)*V_capture_lander);

%% CASO 2:
Beta_capture_2_lander=2*pi-acos(r_dir_capture_lander'*S_vector_capture_lander);                              % Angolo Posizione- Asintoto [rad]
tan_phiA_capture_2_lander=sigma_capture_lander*sin(Beta_capture_2_lander)+sqrt(((1+sigma_capture_lander)^2)...
   -(1+sigma_capture_lander*cos(Beta_capture_2_lander))^2);
e_h_capture_2_lander=sqrt(tan_phiA_capture_2_lander^2+1);                                             % Eccentricita' seconda Iperbole
phiA_capture_2_lander=acos(-1/e_h_capture_2_lander);                                                  % Angolo periastro - asintoto [rad]
phi_capture_2_lander=-(phiA_capture_2_lander-Beta_capture_2_lander);                                            % Anomalia vera Injection iperbole [rad]
% if phi_capture_2_lander<0                                                                      % Controllo anomalia vera - No negativa
%     phi_capture_2_lander=phi_capture_2_lander+2*pi;
% end
r_hyp_capture_2_lander=a_h_capture_lander*(1-e_h_capture_2_lander^2)/...                                     % Raggio in valori iperbolici 
    (1+e_h_capture_2_lander*cos(phi_capture_2_lander));                                               % deve essere uguale a quello dell'orbita
V_h_mod_capture_2_lander=sqrt(C3_c_lander+2*mu/r_hyp_capture_2_lander);                                % Modulo velocità iperbolica [km/s]
h_h_capture_2_lander=mu*sqrt((e_h_capture_2_lander^2-1)/C3_c_lander);                                  % Momento angolare iperbole
fpa_h_capture_2_lander=asin(h_h_capture_2_lander/(r_hyp_capture_2_lander*V_h_mod_capture_2_lander));                % Flight Path Angle Iperbole [rad]
if phi_capture_2_lander<-0.001                                                                 % Condizioni Angoli
    phi_capture_2_lander=phi_capture_2_lander+2*pi;
end
if phi_capture_2_lander>=-0.001 && phi_capture_2_lander<=pi
    if fpa_h_capture_2_lander>=0 && fpa_h_capture_2_lander<=pi/2
        fpa_h_capture_2_lander=fpa_h_capture_2_lander;
    else
        fpa_h_capture_2_lander=fpa_h_capture_2_lander-pi/2;
    end
end
if phi_capture_2_lander>pi && phi_capture_2_lander<2*pi
    if fpa_h_capture_2_lander>pi/2 && fpa_h_capture_2_lander<=pi
        fpa_h_capture_2_lander=fpa_h_capture_2_lander;
    else
        fpa_h_capture_2_lander=pi-fpa_h_capture_2_lander;
    end
end
W_dir_capture_2_lander=cross(S_vector_capture_lander,r_dir_capture_lander)/sin(Beta_capture_2_lander);              % Versore Momento angolare iperbole
V_h_dir_capture_2_lander=(r_dir_capture_lander*cos(fpa_h_capture_2_lander)+...                               % Direzione velocità iperbolica capture
    cross(W_dir_capture_2_lander, r_dir_capture_lander)*sin(fpa_h_capture_2_lander));  

V_h_capture_2_lander=V_h_dir_capture_2_lander*V_h_mod_capture_2_lander;                                      % Velocità iperbolica cattura [km/s]
p_vector_2_lander=1/mu*((V_h_mod_capture_2_lander^2-mu/r_hyp_capture_2_lander)*r_capture_lander-(r_capture_lander'*V_h_capture_2_lander)*V_h_capture_2_lander);

Delta_V_capture_2_lander=sqrt((V_capture_lander-V_h_capture_2_lander)'*(V_capture_lander-V_h_capture_2_lander));       % DeltaV cattura seconda iperbole [km/s]

n_dir_capture_1_lander=cross(Z,W_dir_capture_1_lander);
n_dir_capture_2_lander=cross(Z,W_dir_capture_2_lander);

if Delta_V_capture_1_lander < Delta_V_capture_2_lander
    DV_CAPTURE_lander=Delta_V_capture_1_lander;
    assignin('base', 'nodi_c_lander', A_vector_capture_lander);
    assignin('base','S_vettore_lander',S_vector_capture_lander);
    assignin('base','e_h_capture_lander',e_h_capture_1_lander);
    assignin('base','R_vettore_lander',r_capture_lander);
    assignin('base','a_h_capture_lander',a_h_capture_lander);
    assignin('base','e_h_capture_2_lander',e_h_capture_2_lander);
    assignin('base','phi_A_capture_lander',phiA_capture_1_lander);
    assignin('base','p_vector_lander',p_vector_1_lander);
    assignin('base','p_vector_2_lander',p_vector_2_lander);
    assignin('base','n_capture_lander',n_dir_capture_1_lander)
    assignin('base','n_capture_2_lander',n_dir_capture_2_lander)
    assignin('base','W_h_capture_lander',W_dir_capture_1_lander)
    assignin('base','W_h_capture_2_lander',W_dir_capture_2_lander)
    assignin('base','r_capture_lander',r_capture_lander)
    assignin('base','V_capture_lander',V_capture_lander)
    assignin('base','V_h_capture_lander',V_h_capture_1_lander)
    assignin('base','V_h_capture_2_lander',V_h_capture_2_lander)
    assignin('base','phi_capture_lander',phi_capture_1_lander)
else
    DV_CAPTURE_lander=Delta_V_capture_2_lander;
    assignin('base', 'nodi_c_lander', A_vector_capture_lander);
    assignin('base','S_vettore_lander',S_vector_capture_lander);
    assignin('base','e_h_capture_lander',e_h_capture_2_lander);
    assignin('base','e_h_capture_2_lander',e_h_capture_1_lander);
    assignin('base','R_vettore_lander',r_capture_lander);
    assignin('base','a_h_capture_lander',a_h_capture_lander)
    assignin('base','phi_A_capture_lander',phiA_capture_2_lander);
    assignin('base','p_vector_lander',p_vector_2_lander);
        assignin('base','p_vector_2_lander',p_vector_1_lander);
        assignin('base','n_capture_lander',n_dir_capture_2_lander)
        assignin('base','n_capture_2_lander',n_dir_capture_1_lander)
        assignin('base','W_h_capture_lander',W_dir_capture_2_lander)
        assignin('base','W_h_capture_2_lander',W_dir_capture_1_lander)   
    assignin('base','r_capture_lander',r_capture_lander)
    assignin('base','V_capture_lander',V_capture_lander)
    assignin('base','V_h_capture_lander',V_h_capture_2_lander)
    assignin('base','V_h_capture_2_lander',V_h_capture_1_lander)
    assignin('base','phi_capture_lander',phi_capture_2_lander)
end


DV_TOTAL_lander=DV_CAPTURE_lander;
assignin('base', 'DV_Capture_1_lander', Delta_V_capture_1_lander);
assignin('base', 'DV_Capture_2_lander', Delta_V_capture_2_lander);

%calcolo delle masse all'arrivo su Marte del lander
mu_arrivo_lander=mi_discesa_lander;
M_TOTAL_lander=(mu_arrivo_lander)/(exp(-(DV_CAPTURE_lander/c))-0.1+0.1*(exp(-(DV_CAPTURE_lander/c))));
mp_arrivo_lander=(M_TOTAL_lander-mu_arrivo_lander)/1.1;
ms_arrivo_lander=0.1*mp_arrivo_lander;

%massa totale da minimizzare
M_TOTAL=M_TOTAL_orbiter+M_TOTAL_lander;

end
