function [DV_TOTAL]=mission1_optim_dv(vari)

%% INTRODUZIONE:
% Codice di ottimizzazione dell'orbita di parcheggio marziana.
% INPUT: Condizioni di cattura e fuga dal pianeta in termini di:
% - Eccesso Iperbolico di Velocita' --> Energia Caratteristica C3
% - Data di cattura e di fuga --> Julian Day
% - Dati orbitali di parcheggio --> Eccentricità, Semiasse e Inclinazione
% OUTPUT:
% - Argomento del periastro --> vari(1)
% - Ascensione retta del nodo ascendente orbita di parcheggio --> vari(2)
% - Punto di injection per la cattura --> vari(3)
% - Punto di Injection per la fuga --> vari(4)
% - Eccentricità --> vari(5)
%% DATI DI INPUT --> variIABILI GLOBALI
global a_orbit i_orbit C3_c delta_t Perturbation1 Perturbation2
global ra_capture ra_escape dec_capture dec_escape mu C3_e 
global mi_ritorno mu_ascesa mp_TOTAL deltav_ascesa deltav_discesa mi_ascesa mu_arrivo mp_ascesa mp_arrivo mp_ritorno ms_ascesa
global DV_CAPTURE DV_ESCAPE DV_TOTAL mi_discesa mp_discesa ms_discesa mu_discesa ms_arrivo ms_ritorno 

%% MASSE
mu_ritorno=200; 
mu_ascesa=50; 

Isp_MAV=300;
g0=9.81;
c_MAV=Isp_MAV*g0/1000; 

Isp=450; %LOX/LH2
c=Isp*g0/1000;

%ascesa
r0=3389.5;
rp_MAV=a_orbit*(1-vari(5));
energia=-(mu/(2*a_orbit));
v2=sqrt(2*(energia+mu/rp_MAV));
a1_MAV=(rp_MAV+r0)/2;
energia1=-(mu/(2*a1_MAV));
v0=sqrt(2*(energia1+mu/r0));
v1=sqrt(2*(energia1+mu/rp_MAV));
dv1=v2-v1;
deltav_ascesa=1.1*v0+dv1;
mi_ascesa=mu_ascesa/(exp(-deltav_ascesa/c_MAV)-0.1+0.1*(exp(-deltav_ascesa/c_MAV)));
mp_ascesa=(mi_ascesa-mu_ascesa)/1.1;
ms_ascesa=0.1*mp_ascesa;

%discesa
mu_discesa=900+mi_ascesa;
deltav_discesa=dv1;
mi_discesa=(mu_discesa)/(exp(-(deltav_discesa/c_MAV))-0.1+0.1*(exp(-(deltav_discesa/c_MAV))));
mp_discesa=(mi_discesa-mu_discesa)/1.1;
ms_discesa=0.1*mp_discesa;
 
%% PERTURBAZIONE
t=delta_t*86400; %perturbazione
tao=sqrt(mu/a_orbit^3);
R_mars=3389.5;
J2=1.9595*10^-3;
p_orbit=a_orbit*(1-vari(5)^2);
Perturbation1=-3/2*J2*tao*(R_mars/p_orbit)^2*cos(i_orbit);
Perturbation2=3/2*J2*tao*(R_mars/p_orbit)^2*(2-5/2*sin(i_orbit).^2);

%% VETTORI FONDAMENTALI E MATRICI DI ROTAZIONE
X=[1;0;0];                  
Y=[0;1;0];
Z=[0;0;1];

R_RAAN_3_capture=[cos(vari(2)) -sin(vari(2)) 0;sin(vari(2)) cos(vari(2)) 0;0 0 1];
R_i_1= [1 0 0; 0 cos(i_orbit) -sin(i_orbit);0 sin(i_orbit) cos(i_orbit)];
R_inj_3_capture=[cos(vari(3)) -sin(vari(3)) 0;sin(vari(3)) cos(vari(3)) 0;0 0 1];
R_ra_capture_3=[cos(ra_capture) -sin(ra_capture) 0;sin(ra_capture) cos(ra_capture) 0;0 0 1];
R_dec_capture_2=[cos(dec_capture) 0 sin(dec_capture);0 1 0; -sin(dec_capture) 0 cos(dec_capture)];
R_RAAN_3_escape=[cos(vari(2)+Perturbation1*t) -sin(vari(2)+Perturbation1*t) 0;sin(vari(2)+Perturbation1*t) cos(vari(2)+Perturbation1*t) 0;0 0 1];
R_ra_escape_3=[cos(ra_escape) -sin(ra_escape) 0;sin(ra_escape) cos(ra_escape) 0;0 0 1];
R_dec_escape_2=[cos(dec_escape) 0 sin(dec_escape);0 1 0; -sin(dec_escape) 0 cos(dec_escape)];
R_inj_3_escape=[cos(vari(4)) -sin(vari(4)) 0;sin(vari(4)) cos(vari(4)) 0;0 0 1];

%% FASE DI CATTURA --> DEFINIZIONE PARAMETRI ORBITALI E DV DI CATTURA
A_vector_capture=(R_RAAN_3_capture*R_i_1*X);                        % Vettore nodo ascendente
nu_capture=2*pi+vari(3)-vari(1);                                % Anomalia Vera P.O. [rad]
r_mod_capture=a_orbit*(1-vari(5)^2)/(1+vari(5)*cos(nu_capture));  % Modulo vettore di capture [km]
r_dir_capture=R_RAAN_3_capture*R_i_1*R_inj_3_capture*X;          % Direzione Vettore posizione P.O.
r_capture=r_mod_capture*r_dir_capture;                              % Vettore Posizione P.O. [km]
V_mod_capture=sqrt(2*mu/r_mod_capture-mu/a_orbit);  % Modulo velocità P.O. [km/s]
fpa_capture=asin(sqrt(mu*a_orbit*(1-vari(5)^2))/...               % Flight Path Angle [rad]
    (r_mod_capture*V_mod_capture));                
      
if fpa_capture<0                                   % Condizione Flight Path Angle - No valore negativo
    fpa_capture=fpa_capture+2*pi;
end 
if nu_capture<0                                    % Condizione Anomalia Vera - No valore negativo
    nu_capture=2*pi+nu_capture;
end
angle_capture=vari(3)-vari(1);                       % Angolo tra periastro e posizione - Anomalia vera [rad]

%% MODIFICA - fpa cambia valore solo se sono almeno 1 grado negativo
if angle_capture<-0.01*pi/180                         % No valore negativo
    angle_capture=angle_capture+2*pi;
end
if angle_capture>=-0.01*pi/180 && angle_capture<=pi           % Controllo range del Flight Path Angle 
    if fpa_capture>=0 && fpa_capture<=pi/2         % Prima meta' orbita: 0<fpa<pi/2
        fpa_capture=fpa_capture;                                    
    else
        fpa_capture=fpa_capture-pi/2;
    end
end
if angle_capture>pi && angle_capture<=2*pi          % Seconda meta' orbita: pi/2<fpa<pi
     
     if fpa_capture>pi/2 && fpa_capture<=pi
         fpa_capture=fpa_capture;
     else
         fpa_capture=pi-fpa_capture;
     end            
end
R_fpa_3_capture=[cos(fpa_capture) -sin(fpa_capture) 0;sin(fpa_capture) cos(fpa_capture) 0;0 0 1]; 
V_dir_capture=R_RAAN_3_capture*R_i_1...               % Direzione Velocità capture
    *R_inj_3_capture*R_fpa_3_capture*X;    


V_capture=V_mod_capture*V_dir_capture;                  % Vettore Velocità capture  [km/s]
S_vector_capture=(R_ra_capture_3*R_dec_capture_2'*X);   % Vettore Asintoto iperbole capture
sigma_capture=C3_c*r_mod_capture/(2*mu);            % Parametro adimensionale 
a_h_capture=-mu/C3_c;                             % Semiasse Iperbole [km]
% DEFINIZIONE DELLE IPERBOLE POSSIBILI: definito un asintoto e fissato
% un vettore posizione di injection (modulo e direzione) si trovano due
% iperbole con eccentricità diverse che soddisfano la direzione
% dell'asintoto e il livello energetico (C3).


% CASO 1: 
Beta_capture_1=acos(S_vector_capture'*r_dir_capture);                                   % Angolo Posizione- Asintoto [rad]
 tan_phiA_capture_1=sigma_capture*sin(Beta_capture_1)+sqrt(((1+sigma_capture)^2)...
  -(1+sigma_capture*cos(Beta_capture_1))^2);
e_h_capture_1=sqrt(tan_phiA_capture_1^2+1);                                             % Eccentricita' prima Iperbole
phiA_capture_1=acos(-1/e_h_capture_1);                                                  % Angolo periastro - asintoto [rad]

%%
phi_capture_1=-(phiA_capture_1- Beta_capture_1);                                         % Anomalia vera Injection iperbole [rad]

% if phi_capture_1<0                                                                      % Controllo anomalia vera - No negativa
 %    phi_capture_1=phi_capture_1+2*pi;
 %end
if phi_capture_1>2*pi                                                                      % Controllo anomalia vera - No negativa
    phi_capture_1=phi_capture_1-2*pi;
end
r_hyp_capture_1=a_h_capture*(1-e_h_capture_1^2)/...                                     % Raggio in valori iperbolici
    (1+e_h_capture_1*cos(phi_capture_1));                                               % deve essere uguale a quello dell'orbita
V_h_mod_capture_1=sqrt(C3_c+2*mu/r_hyp_capture_1);                                % Modulo velocità iperbolica [km/s]
h_h_capture_1=mu*sqrt((e_h_capture_1^2-1)/C3_c);                                  % Momento angolare iperbole
fpa_h_capture_1=asin(h_h_capture_1/(r_hyp_capture_1*V_h_mod_capture_1));                % Flight Path Angle Iperbole [rad]
if phi_capture_1<-0.001                                                                 % Condizioni Angoli
    phi_capture_1=phi_capture_1+2*pi;
end
if phi_capture_1>=-0.001 && phi_capture_1<=pi
    if fpa_h_capture_1>=0 && fpa_h_capture_1<=pi/2
        fpa_h_capture_1=fpa_h_capture_1;
    else
        fpa_h_capture_1=fpa_h_capture_1-pi/2;
    end
end
if phi_capture_1>pi && phi_capture_1<2*pi
    if fpa_h_capture_1>pi/2 && fpa_h_capture_1<=pi
        fpa_h_capture_1=fpa_h_capture_1;
    else
        fpa_h_capture_1=pi-fpa_h_capture_1;
    end

end

W_dir_capture_1=cross(S_vector_capture,r_dir_capture)/sin(Beta_capture_1);              % Versore Momento angolare iperbole
V_h_dir_capture_1=(r_dir_capture*cos(fpa_h_capture_1)+...                               % Direzione velocità iperbolica capture
    cross(W_dir_capture_1, r_dir_capture)*sin(fpa_h_capture_1));         
V_h_capture_1=V_h_mod_capture_1*V_h_dir_capture_1;                                      % Velocità iperbolica cattura [km/s]
Delta_V_capture_1=sqrt((V_capture-V_h_capture_1)'*(V_capture-V_h_capture_1));       % DeltaV cattura seconda iperbole [km/s]
p_vector_1=1/mu*((V_h_mod_capture_1^2-mu/r_hyp_capture_1)*r_capture-(r_capture'*V_h_capture_1)*V_h_capture_1);
p_vector_orbit=1/mu*((V_mod_capture^2-mu/r_mod_capture)*r_capture-(r_capture'*V_capture)*V_capture);


%% CASO 2:
Beta_capture_2=2*pi-acos(r_dir_capture'*S_vector_capture);                              % Angolo Posizione- Asintoto [rad]
tan_phiA_capture_2=sigma_capture*sin(Beta_capture_2)+sqrt(((1+sigma_capture)^2)...
   -(1+sigma_capture*cos(Beta_capture_2))^2);
e_h_capture_2=sqrt(tan_phiA_capture_2^2+1);                                             % Eccentricita' seconda Iperbole
phiA_capture_2=acos(-1/e_h_capture_2);                                                  % Angolo periastro - asintoto [rad]
phi_capture_2=-(phiA_capture_2-Beta_capture_2);                                            % Anomalia vera Injection iperbole [rad]
%if phi_capture_2<0                                                                      % Controllo anomalia vera - No negativa
 %    phi_capture_2=phi_capture_2+2*pi;
 %end
r_hyp_capture_2=a_h_capture*(1-e_h_capture_2^2)/...                                     % Raggio in valori iperbolici 
    (1+e_h_capture_2*cos(phi_capture_2));                                               % deve essere uguale a quello dell'orbita
V_h_mod_capture_2=sqrt(C3_c+2*mu/r_hyp_capture_2);                                % Modulo velocità iperbolica [km/s]
h_h_capture_2=mu*sqrt((e_h_capture_2^2-1)/C3_c);                                  % Momento angolare iperbole
fpa_h_capture_2=asin(h_h_capture_2/(r_hyp_capture_2*V_h_mod_capture_2));                % Flight Path Angle Iperbole [rad]
if phi_capture_2<-0.001                                                                 % Condizioni Angoli
    phi_capture_2=phi_capture_2+2*pi;
end
if phi_capture_2>=-0.001 && phi_capture_2<=pi
    if fpa_h_capture_2>=0 && fpa_h_capture_2<=pi/2
        fpa_h_capture_2=fpa_h_capture_2;
    else
        fpa_h_capture_2=fpa_h_capture_2-pi/2;
    end
end
if phi_capture_2>pi && phi_capture_2<2*pi
    if fpa_h_capture_2>pi/2 && fpa_h_capture_2<=pi
        fpa_h_capture_2=fpa_h_capture_2;
    else
        fpa_h_capture_2=pi-fpa_h_capture_2;
    end
end
W_dir_capture_2=cross(S_vector_capture,r_dir_capture)/sin(Beta_capture_2);              % Versore Momento angolare iperbole
V_h_dir_capture_2=(r_dir_capture*cos(fpa_h_capture_2)+...                               % Direzione velocità iperbolica capture
    cross(W_dir_capture_2, r_dir_capture)*sin(fpa_h_capture_2));  

V_h_capture_2=V_h_dir_capture_2*V_h_mod_capture_2;                                      % Velocità iperbolica cattura [km/s]
p_vector_2=1/mu*((V_h_mod_capture_2^2-mu/r_hyp_capture_2)*r_capture-(r_capture'*V_h_capture_2)*V_h_capture_2);

Delta_V_capture_2=sqrt((V_capture-V_h_capture_2)'*(V_capture-V_h_capture_2));       % DeltaV cattura seconda iperbole [km/s]

n_dir_capture_1=cross(Z,W_dir_capture_1);
n_dir_capture_2=cross(Z,W_dir_capture_2);


if Delta_V_capture_1 < Delta_V_capture_2
    DV_CAPTURE=Delta_V_capture_1;
    assignin('base', 'nodi_c', A_vector_capture);
    assignin('base','S_vettore',S_vector_capture);
    assignin('base','e_h_capture',e_h_capture_1);
    assignin('base','R_vettore',r_hyp_capture_1);
    assignin('base','a_h_capture',a_h_capture);
    assignin('base','e_h_capture_2',e_h_capture_2);
    assignin('base','phi_A_capture',phiA_capture_1);
    assignin('base','p_vector',p_vector_1);
    assignin('base','p_vector_2',p_vector_2);
    assignin('base','n_capture',n_dir_capture_1);
    assignin('base','n_capture_2',n_dir_capture_2);
    assignin('base','W_h_capture',W_dir_capture_1);
    assignin('base','W_h_capture_2',W_dir_capture_2);
    assignin('base','r_capture',r_capture);
    assignin('base','V_capture',V_capture);
    assignin('base','V_h_capture',V_h_capture_1);
    assignin('base','V_h_capture_2',V_h_capture_2);
    assignin('base','phi_capture',phi_capture_1);
else
    DV_CAPTURE=Delta_V_capture_2;
    assignin('base', 'nodi_c', A_vector_capture);
    assignin('base','S_vettore',S_vector_capture);
    assignin('base','e_h_capture',e_h_capture_2);
    assignin('base','e_h_capture_2',e_h_capture_1);
    assignin('base','R_vettore',r_hyp_capture_2);
    assignin('base','a_h_capture',a_h_capture);
    assignin('base','phi_A_capture',phiA_capture_2);
    assignin('base','p_vector',p_vector_2);
        assignin('base','p_vector_2',p_vector_1);
        assignin('base','n_capture',n_dir_capture_2);
        assignin('base','n_capture_2',n_dir_capture_1);
        assignin('base','W_h_capture',W_dir_capture_2);
        assignin('base','W_h_capture_2',W_dir_capture_1);   
    assignin('base','r_capture',r_capture);
    assignin('base','V_capture',V_capture);
    assignin('base','V_h_capture',V_h_capture_2);
    assignin('base','V_h_capture_2',V_h_capture_1);
    assignin('base','phi_capture',phi_capture_2);
end


%% FASE DI EVASIONE --> DEFINIZIONE PARAMETRI ORBITALI E DV DI EVASIONE

A_vector_escape=(R_RAAN_3_escape*R_i_1*X);                         % Vettore nodo ascendente
nu_escape=2*pi+vari(4)-(vari(1)+Perturbation2*t);% Anomalia Vera P.O. [rad]
r_mod_escape=a_orbit*(1-vari(5)^2)/(1+vari(5)*cos(nu_escape));   % Modulo vettore di escape [km]
r_dir_escape=R_RAAN_3_escape*R_i_1*R_inj_3_escape*X;            % Direzione Vettore posizione P.O.
r_escape=r_mod_escape*r_dir_escape;                                % Vettore Posizione P.O. [km]
V_mod_escape=sqrt((2*mu/r_mod_escape)-mu/a_orbit);                 % Modulo velocità P.O. [km/s]
fpa_escape=asin(sqrt(mu*a_orbit*(1-vari(5)^2))/...               % Flight Path Angle [rad]
    (r_mod_escape*V_mod_escape));   
if fpa_escape<0                                   % Condizione Flight Path Angle - No valore negativo
    fpa_escape=fpa_escape+2*pi;
end 
if nu_escape<0                                    % Condizione Anomalia Vera - No valore negativo
    nu_escape=2*pi+nu_escape;
end
angle_escape=vari(4)-(vari(1)+Perturbation2*t);                       % Angolo tra periastro e posizione - Anomalia vera [rad]

%% MODIFICA - fpa cambia valore solo se sono almeno 1 grado negativo
if angle_escape<-0.01*pi/180                                % No valore negativo
    angle_escape=angle_escape+2*pi;
end
if angle_escape>=-0.01*pi/180 && angle_escape<=pi            % Controllo range del Flight Path Angle 
    if fpa_escape>=0 && fpa_escape<=pi/2          % Prima meta' orbita: 0<fpa<pi/2
        fpa_escape=fpa_escape;                                    
    else
        fpa_escape=fpa_escape-pi/2;
    end 
end
if angle_escape>pi && angle_escape<2*pi          % Seconda meta' orbita: pi/2<fpa<pi
    fpa_escape=-fpa_escape;
    if fpa_escape>pi/2 && fpa_escape<=pi
        fpa_escape=fpa_escape;
    else
        fpa_escape=pi-fpa_escape;
    end
end

    R_fpa_3_escape=[cos(fpa_escape) -sin(fpa_escape) 0;sin(fpa_escape) cos(fpa_escape) 0;0 0 1]; 
V_dir_escape=R_RAAN_3_escape*R_i_1...               % Direzione Velocità escape
    *R_inj_3_escape*R_fpa_3_escape*X;                
V_escape=V_mod_escape*V_dir_escape;                   % Vettore Velocità escape  [km/s]
S_vector_escape=(R_ra_escape_3*R_dec_escape_2'*X);    % Vettore Asintoto iperbole escape
sigma_escape=C3_e*r_mod_escape/(2*mu);             % Parametro adimensionale 
a_h_escape=-mu/C3_e;                             % Semiasse Iperbole [km]

% DEFINIZIONE DELLE IPERBOLE POSSIBILI: definito un asintoto e fissato
% un vettore posizione di injection (modulo e direzione) si trovano due
% iperbole con eccentricità diverse che soddisfano la direzione
% dell'asintoto e il livello energetico (C3).

% CASO 1: 
Beta_escape_1=acos(r_dir_escape'*S_vector_escape);                                   % Angolo Posizione- Asintoto [rad]
tan_phiA_escape_1=-sigma_escape*sin(Beta_escape_1)-sqrt((1+sigma_escape)^2 ...
    -(1+sigma_escape*cos(Beta_escape_1))^2);
e_h_escape_1=sqrt(tan_phiA_escape_1^2+1);                                             % Eccentricita' prima Iperbole
phiA_escape_1=acos(-1/e_h_escape_1);                                                  % Angolo periastro - asintoto [rad]
phi_escape_1=(phiA_escape_1-Beta_escape_1);                                             % Anomalia vera Injection iperbole [rad]
%if phi_escape_1<0                                                                     % Controllo anomalia vera - No negativa
 %  phi_escape_1=phi_escape_1+2*pi;
%end
r_hyp_escape_1=a_h_escape*(1-e_h_escape_1^2)/...                                      % Raggio in valori iperbolici 
    (1+e_h_escape_1*cos(phi_escape_1));                                               % deve essere uguale a quello dell'orbita
V_h_mod_escape_1=sqrt(C3_e+2*mu/r_hyp_escape_1);                                 % Modulo velocità iperbolica [km/s]
h_h_escape_1=mu*sqrt((e_h_escape_1^2-1)/C3_e);                                   % Momento angolare iperbole
fpa_h_escape_1=asin(h_h_escape_1/(r_hyp_escape_1*V_h_mod_escape_1));                  % Flight Path Angle Iperbole [rad]
if phi_escape_1<-0.001                                                                % Condizioni Angoli
    phi_escape_1=phi_escape_1+2*pi;
end
if phi_escape_1>=-0.001 && phi_escape_1<=pi
    if fpa_h_escape_1>=0 && fpa_h_escape_1<=pi/2
        fpa_h_escape_1=fpa_h_escape_1;
    else
        fpa_h_escape_1=fpa_h_escape_1-pi/2;
    end
end
if phi_escape_1>pi && phi_escape_1<2*pi
    if fpa_h_escape_1>pi/2 && fpa_h_escape_1<=pi
        fpa_h_escape_1=fpa_h_escape_1;
    else
        fpa_h_escape_1=pi-fpa_h_escape_1;
    end
end
%%
%W_dir_escape_1=cross(S_vector_escape,r_dir_escape)/sin(-Beta_escape_1);
W_dir_escape_1=cross(r_dir_escape,S_vector_escape)/sin(Beta_escape_1);               % Versore Momento angolare iperbole
V_h_dir_escape_1=(r_dir_escape*cos(fpa_h_escape_1)+...                               % Direzione velocità iperbolica escape
    cross(W_dir_escape_1, r_dir_escape)*sin(fpa_h_escape_1));         
V_h_escape_1=V_h_dir_escape_1*V_h_mod_escape_1;                                      % Velocità iperbolica cattura [km/s]
Delta_V_escape_1=sqrt((V_escape-V_h_escape_1)'*(V_escape-V_h_escape_1));             % DeltaV cattura seconda iperbole [km/s]
p_escape_1=1/mu*((V_h_mod_escape_1^2-mu/r_hyp_escape_1)*r_escape-(r_escape'*V_h_escape_1)*V_h_escape_1);
% CASO 2:
Beta_escape_2=2*pi-acos(r_dir_escape'*S_vector_escape);                              % Angolo Posizione- Asintoto [rad]
tan_phiA_escape_2=-sigma_escape*sin(Beta_escape_2)-sqrt(((1+sigma_escape)^2)...
    -(1+sigma_escape*cos(Beta_escape_2))^2);
e_h_escape_2=sqrt(tan_phiA_escape_2^2+1);                                            % Eccentricita' seconda Iperbole
phiA_escape_2=acos(-1/e_h_escape_2);                                                 % Angolo periastro - asintoto [rad]
phi_escape_2=(phiA_escape_2-Beta_escape_2);                                            % Anomalia vera Injection iperbole [rad]
% if phi_escape_2<0                                                                    % Controllo anomalia vera - No negativa
 %   phi_escape_2=phi_escape_2+2*pi;
 %end
r_hyp_escape_2=a_h_escape*(1-e_h_escape_2^2)/...                                     % Raggio in valori iperbolici 
    (1+e_h_escape_2*cos(phi_escape_2));                                              % deve essere uguale a quello dell'orbita
V_h_mod_escape_2=sqrt(C3_e+2*mu/r_hyp_escape_2);                                % Modulo velocità iperbolica [km/s]
h_h_escape_2=mu*sqrt((e_h_escape_2^2-1)/C3_e);                                  % Momento angolare iperbole
fpa_h_escape_2=asin(h_h_escape_2/(r_hyp_escape_2*V_h_mod_escape_2));                 % Flight Path Angle Iperbole [rad]
if phi_escape_2<-0.001                                                               % Condizioni Angoli
    phi_escape_2=phi_escape_2+2*pi;
end
if phi_escape_2>=-0.001 && phi_escape_2<=pi
    if fpa_h_escape_2>=0 && fpa_h_escape_2<=pi/2
        fpa_h_escape_2=fpa_h_escape_2;
    else
        fpa_h_escape_2=fpa_h_escape_2-pi/2;
    end
end
%%
if phi_escape_2>pi && phi_escape_2<2*pi
    if fpa_h_escape_2>pi/2 && fpa_h_escape_2<=pi
        fpa_h_escape_2=fpa_h_escape_2;
    else
        fpa_h_escape_2=pi-fpa_h_escape_2;
    end
end
%%
%W_dir_escape_2=cross(S_vector_escape,r_dir_escape)/sin(-Beta_escape_2);               % Versore Momento angolare iperbole
W_dir_escape_2=cross(r_dir_escape,S_vector_escape)/sin(Beta_escape_2);
V_h_dir_escape_2=(r_dir_escape*cos(fpa_h_escape_2)+...                               % Direzione velocità iperbolica escape
    cross(W_dir_escape_2, r_dir_escape)*sin(fpa_h_escape_2));         
V_h_escape_2=V_h_dir_escape_2*V_h_mod_escape_2;                                      % Velocità iperbolica cattura [km/s]
Delta_V_escape_2=sqrt((V_escape-V_h_escape_2)'*(V_escape-V_h_escape_2));         % DeltaV cattura seconda iperbole [km/s]
p_escape_2=1/mu*((V_h_mod_escape_2^2-mu/r_hyp_escape_2)*r_escape-(r_escape'*V_h_escape_2)*V_h_escape_2);


n_dir_escape_1=cross(Z,W_dir_escape_1);
n_dir_escape_2=cross(Z,W_dir_escape_2);

if Delta_V_escape_1 < Delta_V_escape_2
    DV_ESCAPE=Delta_V_escape_1;
    assignin('base', 'nodi_e', A_vector_escape);
    assignin('base','S_vettore_e',S_vector_escape);
    assignin('base','e_h_escape',e_h_escape_1);
    assignin('base','e_h_escape_2',e_h_escape_2);
    assignin('base','R_vettore_e',r_hyp_escape_1);
    assignin('base','a_h_escape',a_h_escape);
    assignin('base','phi_A_escape',phiA_escape_1);
    assignin('base', 'p_escape',p_escape_1);
        assignin('base', 'p_escape_2',p_escape_2);
        assignin('base','n_escape',n_dir_escape_1);
        assignin('base','n_escape_2',n_dir_escape_2);
        assignin('base','W_h_escape',W_dir_escape_1);
        assignin('base','W_h_escape_2',W_dir_escape_2)
            assignin('base','r_escape',r_escape)
    assignin('base','V_escape',V_escape)
    assignin('base','V_h_escape',V_h_escape_1)
    assignin('base','V_h_escape_2',V_h_escape_2)
    assignin('base','phi_escape',phi_escape_1)
    
else
    DV_ESCAPE=Delta_V_escape_2;
    assignin('base', 'nodi_e', A_vector_escape);
    assignin('base','S_vettore_e',S_vector_escape);
    assignin('base','e_h_escape',e_h_escape_2);
    assignin('base','e_h_escape_2',e_h_escape_1);
    assignin('base','R_vettore_e',r_hyp_escape_2);
    assignin('base','a_h_escape',a_h_escape);
    assignin('base','phi_A_escape',phiA_escape_2);
    assignin('base', 'p_escape',p_escape_2);
        assignin('base', 'p_escape_2',p_escape_1);
        assignin('base','n_escape',n_dir_escape_2)
        assignin('base','n_escape_2',n_dir_escape_1)
        assignin('base','W_h_escape',W_dir_escape_2)
        assignin('base','W_h_escape_2',W_dir_escape_1)
    assignin('base','r_escape',r_escape)
    assignin('base','V_escape',V_escape)
    assignin('base','V_h_escape',V_h_escape_2)
    assignin('base','V_h_escape_2',V_h_escape_1)
    assignin('base','phi_escape',phi_escape_2)
end
DV_TOTAL=DV_CAPTURE+DV_ESCAPE;
assignin('base', 'DV_Capture_1', Delta_V_capture_1);
assignin('base', 'DV_Capture_2', Delta_V_capture_2);
assignin('base', 'DV_Escape_1', Delta_V_escape_1);
assignin('base', 'DV_Escape_2', Delta_V_escape_2);

mi_ritorno=(mu_ritorno)/(exp(-(DV_ESCAPE/c))-0.1+0.1*(exp(-(DV_ESCAPE/c))));
mp_ritorno=(mi_ritorno-mu_ritorno)/1.1;
ms_ritorno=0.1*mp_ritorno;

mu_arrivo=mi_ritorno+mi_discesa;
M_TOTAL=(mu_arrivo)/(exp(-(DV_CAPTURE/c))-0.1+0.1*(exp(-(DV_CAPTURE/c))));
mp_arrivo=(M_TOTAL-mu_arrivo)/1.1;
ms_arrivo=0.1*mp_arrivo;

mp_TOTAL=mp_arrivo+mp_discesa+mp_ascesa+mp_ritorno;

end
